bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge Nôt ## 34. Aventiure
___________________________________________________ #### Aventivre wie si toten #### abe wvrfen
###### 2009 | ### Di herren nach ir mvede | sazen do ce tal ### volker vnde hagene | giengen fver den sal ### sich leinten veber schilde | di vebermvten man ### do wart da rede vil spaehe | von in beiden getan
###### 2010 | ### do sprach von bvergonden | giselher der degen ### ia ne mveget ir liebe vrivnde | ruwe niht gepflegen ### ir svlt di toten livte | vz dem hvse tragen ### wir werden noch bestanden | ich wilz iv waerliche sagen
###### 2011 | ### si ne svln vns vnder fvezen | hi niht langer ligen ### e daz vns di hivnen | mit stvrme an gesigen ### wir gehauowen noch di wunden | di mir sanfte tvt ### des han ich sprach do giselher | einen staetigen mvt
###### 2012 | ### so wol mich soelhes herren | sprach do hagene ### der rat en zaeme niemen | wan einem degene ### den vns min ivnger herre | hivte hat getan ### des mveget ir bvergonden | alle vil vroeliche stan
###### 2013 | ### do volgeten si dem rate | vnt tvrgen fver di tver ### siben tvsent toten | wurfen si darfver ### vor des sales stiegen | da vielen si ce tal ### do hvb sich von ir magen | ein vil chlagelicher schal
###### 2014 | ### ez was ir etelicher | so maezlichen wunt ### der sin sapfter pflaege | er wuerde noch gesvnt ### der vor dem hohen valle | mvese ligen tot ### daz chlageten do ir frivnde | des gi in waerliche not
###### 2015 | ### do sprach der videlaere | volker ein helt gemeit ### nv chivse ich des die warheit | als mir ist geseit ### di hivnen di sint boese | si clagent sam div wip ### nv solden si bervchen | der vil sere wunden lip
###### 2016 | ### do wande ein margrave | er riet iz dvrch gvt ### er sach einen sinen mach | gevallen in daz plvt ### er besloz in mit den armen | vnde wold in tragen dan ### den schoz ob im ce tode | der vil chvene spileman
###### 2017 | ### do daz di ander sahen | div flvht div hvop sich dan ### si begonden alle vlvchen | dem selbem spileman ### einen gere er vf gezvchte | vil scharpf vnde vil hart ### der von einem hivnen | zv zim darvf geschozen wart
###### 2018 | ### den shoz er crepftelichen | dvrch di bvrch dan ### veber daz volch vil verre | den eceln man ### gab er herberge | hoher von dem sal ### sin vil starchez ellen | di livte forhten veber al
###### 2019 | ### do stvnden vor dem hvse | vil manech tvsent man ### volker vnde hagene | reden do began ### mit ecel dem chvenege | allen iren mvt ### des chomen sit in sorge | di helde chvene vnd gvt
###### 2020 | ### ez zaeme so sprach hagene | vil wol volches trost ### daz di herren vehten | zaller vorderost ### also der minen herren | hi ieslicher tvt ### di howent dvrch di helme | nach swerten vlivzet daz plvt
###### 2021 | ### ecel was so chvene | er vazete sinen schilt ### nv vart gewerliche | sprach vrov criemhilt ### vnde bietet ir den recken | daz golt veber rant ### wande erreichet ivch dort hagene | ir habt den tot an der hant
###### 2022 | ### der chvenech der was so chvene | er wold erwinden niht ### daz von so richem fversten | vil selten nv geschit ### man mvse in bi dem vezel | ziehen wider dan ### hagen der grimme | in aber hoenen began
###### 2023 | ### ez was ein verriv sippe | sprach hagen der degen ### di ecel vnde sifrit | cesamne heten gepflegen ### er minnete criemhilden | e si ie gesaehe dich ### kvenech vil boese | warvmbe raetest an mich
###### 2024 | ### dise rede horte | des edeln chveneges wip ### des wart in vngemvete | der criemhilde lip ### daz er si getorste shelten | vor eceln man ### darvmbe si aber raten | an di geste began
###### 2025 | ### si sprach der mir von tronege | hagenen slvege ### vnde mir sin hovbet | her fver mich trvege ### dem fvlt ich rotes goldes | den eceln rant ### darzv gaebe ich im ce miete | vil gvte bverge vnde lant
###### 2026 | ### nv weiz ich wes si bitent | sprach der spilman ### ine gesach ni helde | so zaegelichen stan ### da man horte bieten | also hohen solt ### ia ne sol in ecel | darvmbe nimmer werden holt
###### 2027 | ### di hi so lasterlichen | ezzent des fversten brot ### vnde im nv geswichent | in der groezesten not ### der sihe ich hi vil manegen | vil zageliche stan ### vnde wellent doch sin vil chvene | si mvzens immer schaden han

<<< Übersicht <<< vorige Seite nächste Seite >>>